import { Component, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialogRef } from '@angular/material/dialog';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-create-command-group',
  templateUrl: './create-command-group.component.html',
  styleUrls: ['./create-command-group.component.css']
})
export class CreateCommandGroupComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  availableCommands: any[] = [];
  selectedCommands: any[] = [];
  groupName: string = '';
  position: number = 1;
  enabled: boolean = true;
  
  private apiUrl = 'http://127.0.0.1:8001/commands'; 

  constructor(
    private http: HttpClient,
    private dialogRef: MatDialogRef<CreateCommandGroupComponent>,
    private toastService: ToastrService
  ) {}

  ngOnInit(): void {
    this.loadAvailableCommands();
  }

  loadAvailableCommands(): void {
    this.http.get<any>(this.apiUrl).subscribe(
      (data) => {
        this.availableCommands = data['hydra:member']; 
      },
      (error) => {
        console.error('Error fetching available commands', error);
      }
    );
  }

  addCommand(command: any): void {
    this.selectedCommands.push(command);
  }

  removeCommand(command: any): void {
    const index = this.selectedCommands.indexOf(command);
    if (index >= 0) {
      this.selectedCommands.splice(index, 1);
    }
  }

  onSubmit(): void {
    const payload = {
      name: this.groupName,
      commands: this.selectedCommands.map(cmd => cmd['@id']), 
      position: this.position,
      enabled: this.enabled
    };

    console.log('Payload', payload);
    this.http.post('http://127.0.0.1:8001/command-groups', payload).subscribe({
      next: () => {
        this.toastService.success('Grupo de comandos creado con éxito');
        this.dialogRef.close();
      },
      error: (error) => {
        console.error('Error creando el grupo de comandos', error);
      }
    });
  }

  close(): void {
    this.dialogRef.close();
  }
}
