import { Component, OnInit, Inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { ToastrService } from 'ngx-toastr';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';

@Component({
  selector: 'app-create-task',
  templateUrl: './create-task.component.html',
  styleUrls: ['./create-task.component.css']
})
export class CreateTaskComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  taskForm: FormGroup;
  availableCommandGroups: any[] = [];
  selectedGroupCommands: any[] = [];
  apiUrl = `${this.baseUrl}/command-tasks`;

  constructor(
    private fb: FormBuilder,
    private http: HttpClient,
    private toastr: ToastrService,
    public dialogRef: MatDialogRef<CreateTaskComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) {
    this.taskForm = this.fb.group({
      commandGroup: ['', Validators.required],
      date: ['', Validators.required],   
      time: ['', Validators.required],   
      notes: ['']
    });
  }

  ngOnInit(): void {
    this.loadCommandGroups();
  }

  loadCommandGroups(): void {
    this.http.get<any>(`${this.baseUrl}/command-groups`).subscribe(
      (data) => {
        this.availableCommandGroups = data['hydra:member'];
      },
      (error) => {
        this.toastr.error('Error al cargar los grupos de comandos');
      }
    );
  }

  onCommandGroupChange(): void {
    const selectedGroupId = this.taskForm.get('commandGroup')?.value;
    this.http.get<any>(`${this.baseUrl}/command-groups/${selectedGroupId}`).subscribe(
      (data) => {
        this.selectedGroupCommands = data.commands;
      },
      (error) => {
        this.toastr.error('Error al cargar los comandos del grupo seleccionado');
      }
    );
  }

  saveTask(): void {
    if (this.taskForm.invalid) {
      this.toastr.error('Por favor, rellene todos los campos obligatorios');
      return;
    }

    const formData = this.taskForm.value;
    const dateTime = this.combineDateAndTime(formData.date, formData.time);  

    const payload = {
      commandGroups: '/command-groups/'+formData.commandGroup,
      commands: this.selectedGroupCommands.map(cmd => cmd['@id']),
      dateTime: dateTime,
      notes: formData.notes || ''
    };
    console.log(payload);
    stop;
    this.http.post<any>(this.apiUrl, payload).subscribe({
      next: () => {
        this.toastr.success('Tarea creada con éxito');
        this.dialogRef.close(true);
      },
      error: () => {
        this.toastr.error('Error al crear la tarea');
      }
    });
  }

  combineDateAndTime(date: string, time: string): string {
    const dateObj = new Date(date);
    const [hours, minutes] = time.split(':').map(Number);

    dateObj.setHours(hours, minutes, 0);  
    return dateObj.toISOString();         // Return in ISO format (e.g., 2021-10-01T00:00:00+00:00)
  }

  close(): void {
    this.dialogRef.close();
  }
}
